import { Link } from 'react-router-dom';
import { FaStar } from 'react-icons/fa';

function MediaCard({ media }) {
  const { id, title, poster, rating, releaseDate, type } = media;
  
  return (
    <Link to={`/media/${id}`} className="block">
      <div className="card group h-full">
        <div className="relative overflow-hidden aspect-[2/3]">
          <img
            src={poster}
            alt={title}
            className="w-full h-full object-cover transform group-hover:scale-105 transition-transform duration-300"
            loading="lazy"
          />
          <div className="absolute top-2 right-2 bg-campfire-dark bg-opacity-75 rounded-full px-2 py-1 flex items-center">
            <FaStar className="text-campfire-amber mr-1" size={14} />
            <span className="text-sm font-medium">
              {rating ? (rating / 2).toFixed(1) : 'N/A'}
            </span>
          </div>
        </div>
        <div className="p-4">
          <h3 className="font-bold text-campfire-light line-clamp-1 mb-1">
            {title}
          </h3>
          <div className="text-sm text-campfire-ash">
            {new Date(releaseDate).getFullYear()}
          </div>
        </div>
      </div>
    </Link>
  );
}

export default MediaCard;